//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
// 
// uIOStream.h -- 
// 
// Author           : Peter Buhr
// Created On       : Tue Mar 29 16:49:28 1994
// Last Modified By : Peter A. Buhr
// Last Modified On : Sun Jul 31 20:20:45 2005
// Update Count     : 8
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __U_IOSTREAM_H__
#define __U_IOSTREAM_H__
#warning uIOStream.h deprecated: use C++ iostream


#include <uOStream.h>
#include <uIStream.h>


#endif // __U_IOSTREAM_H__


// Local Variables: //
// compile-command: "gmake install" //
// End: //
